%global somajor 8

Name:           ode
Version:        0.16.5
Release:    1%{?dist}
Summary:        High performance library for simulating rigid body dynamics
License:        BSD-3-Clause AND LGPL-2.1-or-later
URL:            https://bitbucket.org/odedevs/ode
Source0:        https://bitbucket.org/odedevs/ode/downloads/ode-%{version}.tar.gz
Patch1:         ode-0.11.1-multilib.patch
Patch2:         ode-0.13.1-double-config.patch
Patch3:         ode-0.16.3-single-config.patch
BuildRequires:  make gcc-c++
BuildRequires:  libGL-devel libGLU-devel libtool

%description
ODE is an open source, high performance library for simulating rigid body
dynamics. It is fully featured, stable, mature and platform independent with
an easy to use C/C++ API. It has advanced joint types and integrated collision
detection with friction. ODE is useful for simulating vehicles, objects in
virtual reality environments and virtual creatures. It is currently used in
many computer games, 3D authoring tools and simulation tools.


%package        double
Summary:        Ode physics library compiled with double precision

%description    double
The %{name}-double package contains a version of the ODE library for simulating
rigid body dynamics compiled with double precision.


%package        devel
Summary:        Development files for %{name}
Requires:       %{name} = %{version}-%{release}
Requires:       %{name}-double = %{version}-%{release}

%description    devel
The %{name}-devel package contains libraries and header files for
developing applications that use %{name} or %{name}-double.


%prep
%setup -q
./bootstrap
%patch -P 1 -p1
sed -i 's/libode_la_LDFLAGS = @EXTRA_LIBTOOL_LDFLAGS@/libode_la_LDFLAGS = $(EXTRA_LIBTOOL_LDFLAGS)/' \
  ode/src/Makefile.in
mv OPCODE/COPYING OPCODE-COPYING
for i in ou/LICENSE*.TXT; do
  sed -i.bak 's/\r//' $i
  touch -r $i.bak $i
  mv $i `echo $i|sed 's|ou/LICENSE|OU-LICENSE|'`
done
mv libccd/BSD-LICENSE LIBCCD-LICENSE.TXT


%build
ODE_CONFIGURE_FLAGS="--enable-shared --disable-static --with-libccd=internal \
  --with-cylinder-cylinder=libccd --with-capsule-cylinder=libcdd \
  --with-convex-box=libccd --with-convex-capsule=libccd \
  --with-convex-cylinder=libccd"
%configure $ODE_CONFIGURE_FLAGS --enable-double-precision
make %{?_smp_mflags} X_LIBS=-lX11 EXTRA_LIBTOOL_LDFLAGS="-release double"
mv ode-config ode-double-config
mv ode.pc ode-double.pc
patch -p1 < %{PATCH2}
mv ode/src/.libs/libode-double.so.%{somajor}.?.? .
make distclean

CFLAGS="%{optflags} -ffast-math"
CXXFLAGS="%{optflags} -ffast-math"
%configure $ODE_CONFIGURE_FLAGS
make %{?_smp_mflags} X_LIBS=-lX11
patch -p1 < %{PATCH3}


%install
make install DESTDIR=%{buildroot}
rm %{buildroot}%{_libdir}/libode.la
install -m 755 ode-double-config %{buildroot}%{_bindir}
install -m 755 libode-double.so.%{somajor}.?.? %{buildroot}%{_libdir}
ln -s libode-double.so.%{somajor}.?.? %{buildroot}%{_libdir}/libode-double.so.%{somajor}
ln -s libode-double.so.%{somajor}.?.? %{buildroot}%{_libdir}/libode-double.so
install -m 644 ode-double.pc %{buildroot}%{_libdir}/pkgconfig


%post -p /sbin/ldconfig
%postun -p /sbin/ldconfig
%post -p /sbin/ldconfig double
%postun -p /sbin/ldconfig double


%files
%doc CHANGELOG.txt README.md
%license *COPYING *LICENSE*.TXT
%{_libdir}/libode.so.%{somajor}*

%files double
%doc CHANGELOG.txt README.md
%license *COPYING *LICENSE*.TXT
%{_libdir}/libode-double.so.%{somajor}*

%files devel
%{_bindir}/%{name}-config
%{_bindir}/%{name}-double-config
%{_includedir}/%{name}
%{_libdir}/libode.so
%{_libdir}/libode-double.so
%{_libdir}/pkgconfig/%{name}.pc
%{_libdir}/pkgconfig/%{name}-double.pc


%changelog
* Wed Jul 24 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 0.16.5-1
- initial build
